@@ -1,4 +1,4 @@
-#!/usr/share/ucs-test/runner /usr/bin/py.test-3 -s
+#!/usr/share/ucs-test/runner pytest-3 -s
 # -*- coding: utf-8 -*-
 ## desc: Test various things in users/user
 ## exposure: dangerous
@@ -6,22 +6,21 @@
 ## packages: [python3-univention-directory-manager]
 ## timeout: 0
 
-from __future__ import print_function
-
-import sys
 import base64
-import pytest
-import time
 import calendar
-from datetime import datetime, timedelta
 import subprocess
+import sys
+import time
+from datetime import datetime, timedelta
+
+import pytest
 from M2Crypto import X509
 
 from univention.config_registry import handler_set
 from univention.testing.strings import random_username
-from univention.testing.utils import wait_for_connector_replication
-from univention.testing.udm import UCSTestUDM_NoModification
 from univention.testing.ucr import UCSTestConfigRegistry
+from univention.testing.udm import UCSTestUDM_NoModification
+from univention.testing.utils import wait_for_connector_replication
 
 
 class TestUsers(object):
