@@ -13,11 +13,12 @@
 ## exposure: dangerous
 
 
+import time
 import email
 
 import pytest
 import selenium.common.exceptions as selenium_exceptions
-from selenium.common.exceptions import NoSuchElementException
+from selenium.common.exceptions import TimeoutException
 from six.moves.urllib_parse import parse_qs, urlparse
 from test_self_service import capture_mails
 
@@ -105,26 +106,32 @@ def _get_mail(mails, idx=-1):
 		'verify_link': verify_link,
 		'verify_data': {
 			'username': verify_params.get('username', [''])[0],
-			'token': verify_params.get('token', [''])[0],
+			'token': verify_params.get('/selfservice/verifyaccount/?token', [''])[0],
 			'method': verify_params.get('method', [''])[0],
 		}
 	}
 
 
-def _enter_attributes(selenium, attributes, button=None):
+def click_submit(selenium):
+	try:
+		selenium.driver.find_elements_by_css_selector(".primary")[0].click()
+	except IndexError:
+		selenium.driver.find_element_by_xpath("//*[@id='modal-wrapper--isVisible-1']/section/form/footer/button").click()
+
+
+def _enter_attributes(selenium, attributes, button=True):
 	for k, v in attributes.items():
 		if k == 'password':
-			selenium.enter_input('password_1', v)
-			selenium.enter_input('password_2', v)
+			selenium.enter_input('password', v)
+			selenium.enter_input('password--retype', v)
 		else:
 			selenium.enter_input(k, v)
 	if button:
-		selenium.click_button(button)
-		selenium.wait_until_standby_animation_appears_and_disappears()
+		click_submit(selenium)
 
 
 def _navigate_self_service(selenium, _hash=None):
-	url = selenium.base_url + 'univention/self-service/'
+	url = selenium.base_url + 'univention/portal/#/selfservice/'
 	selenium.driver.get(url)
 	if _hash:
 		selenium.driver.get(url + _hash)
@@ -140,31 +147,32 @@ def test_registration_enabled(selenium, ucr, get_registration_info):
 		'umc/self-service/account-registration/frontend/enabled=true',
 		'umc/self-service/account-registration/backend/enabled=false',
 	])
-	_navigate_self_service(selenium, '#page=createaccount')
+	_navigate_self_service(selenium, 'createaccount')
 	selenium.wait_for_text('Create an account', 2)
 	info = get_registration_info()
-	_enter_attributes(selenium, info['attributes'], 'Create account')
+	time.sleep(3)
+	_enter_attributes(selenium, info['attributes'])
 	selenium.wait_for_text('The account registration was disabled via the Univention Configuration Registry.')
 
 
 # tests existence of all attributes umc/self-service/registration/udm_attributes
 def test_udm_attributes(selenium, ucr):
-	_navigate_self_service(selenium, '#page=createaccount')
-	selenium.wait_until_element_visible('//h2[text()="Create an account"]')
+	_navigate_self_service(selenium, 'createaccount')
+	selenium.wait_for_text('Create an account', 2)
 	selenium.wait_until_element_visible('//label[contains(text(), "Email")]')
 	selenium.wait_until_element_visible('//label[contains(text(), "Password")]')
 	selenium.wait_until_element_visible('//label[contains(text(), "Password (retype)")]')
-	selenium.wait_until_element_visible('//label[text()="First name"]')
+	selenium.wait_until_element_visible('//label[contains(text(), "First name")]')
 	selenium.wait_until_element_visible('//label[contains(text(), "Last name")]')
 	selenium.wait_until_element_visible('//label[contains(text(), "User name")]')
 	ucr.handler_set(['umc/self-service/account-registration/udm_attributes=description,title'])
 	ucr.handler_set(['umc/self-service/account-registration/udm_attributes/required=title'])
-	_navigate_self_service(selenium, '#page=createaccount')
-	selenium.wait_until_element_visible('//h2[text()="Create an account"]')
+	_navigate_self_service(selenium, 'createaccount')
+	selenium.wait_for_text('Create an account', 2)
 	selenium.wait_until_element_visible('//label[contains(text(), "Email")]')
 	selenium.wait_until_element_visible('//label[contains(text(), "Password")]')
 	selenium.wait_until_element_visible('//label[contains(text(), "Password (retype)")]')
-	selenium.wait_until_element_visible('//label[text()="Description"]')
+	selenium.wait_until_element_visible('//label[contains(text(), "Description")]')
 	selenium.wait_until_element_visible('//label[contains(text(), "Title")]')
 
 
@@ -172,126 +180,125 @@ def test_udm_attributes(selenium, ucr):
 @pytest.mark.parametrize("verification_process", ['automatic', 'manual'])
 def test_user_creation(selenium, mails, get_registration_info, verification_process):
 	# creates user
-	_navigate_self_service(selenium, '#page=createaccount')
+	_navigate_self_service(selenium, 'createaccount')
 	info = get_registration_info()
-	_enter_attributes(selenium, info['attributes'], 'Create account')
+	time.sleep(2)
+	_enter_attributes(selenium, info['attributes'])
+	time.sleep(2)
 	utils.verify_ldap_object(info['dn'], {
 		'univentionRegisteredThroughSelfService': ['TRUE'],
 		'univentionPasswordRecoveryEmailVerified': ['FALSE'],
-	})
-	send_text = ', we have sent you an email to '
-	verify_text = '. Please follow the instructions in the email to verify your account.'
-	selenium.driver.find_element_by_xpath(
-		'//p[text()="Hello "]/b[text()="{}"]//parent::p[text()="{}"]/b[text()="{}"]//parent::p[text()="{}"]'.format(
-			info['attributes']['username'], send_text, info['attributes']['PasswordRecoveryEmail'], verify_text
-		)
-	)
+	}, retry_count=1, delay=2)
+	selenium.wait_for_text('Account creation successful')
 	# tests email
 	mail = _get_mail(mails)
 	if verification_process == 'automatic':
 		# tests automatic link
 		selenium.driver.get(mail['auto_verify_link'])
 		selenium.wait_until_standby_animation_appears_and_disappears()
+		click_submit(selenium)
+		time.sleep(2)
 	elif verification_process == 'manual':
 		# tests manual link
 		selenium.driver.get(mail['verify_link'])
+		print(mail['verify_data']['token'])
 		_enter_attributes(selenium, {
 			'username': mail['verify_data']['username'],
 			'token': mail['verify_data']['token'],
-		}, 'Verify account')
-	selenium.driver.find_element_by_xpath('//p[text()="Welcome "]/b[text()="{}"]//parent::p[text()=", your account has been successfully verified."]'.format(info['attributes']['username']))
-	selenium.driver.find_element_by_xpath('//p[text()="Continue to the "]/a[text()="Univention Portal"]')
+		})
+	selenium.wait_for_text('Your account has been successfully verified')
 	utils.verify_ldap_object(info['dn'], {
 		'univentionRegisteredThroughSelfService': ['TRUE'],
 		'univentionPasswordRecoveryEmailVerified': ['TRUE'],
-	})
+	}, retry_count=1, delay=2)
 
 
 def test_account_verifyaccount_page_errors(selenium, udm, get_registration_info):
-	_navigate_self_service(selenium, '#page=verifyaccount')
+	_navigate_self_service(selenium, 'verifyaccount')
 	_enter_attributes(selenium, {
 		'username': 'not_existing',
 		'token': 'xxxx'
-	}, 'Verify account')
+	})
+	time.sleep(2)
 	selenium.wait_for_text('The account could not be verified. Please verify your input.')
-	_navigate_self_service(selenium, '#page=verifyaccount')
+	_navigate_self_service(selenium, 'verifyaccount')
 	_enter_attributes(selenium, {
-		'username': 'not_existing',
-		'token': 'xxxx'
-	}, 'Request new token')
-	selenium.wait_for_text('A verification token could not be sent. Please verify your input.')
+		'username': 'not_existing'
+	})
+	selenium.wait_for_text('The verification token could not be sent. Please verify your input.')
 	_, username = udm.create_user(**{'PasswordRecoveryEmail': None})
-	_navigate_self_service(selenium, '#page=verifyaccount')
+	_navigate_self_service(selenium, 'verifyaccount')
 	_enter_attributes(selenium, {
 		'username': username,
 		'token': 'xxxx'
-	}, 'Request new token')
-	selenium.wait_for_text('A verification token could not be sent. Please verify your input.')
+	})
+	selenium.wait_for_text('The token you supplied is either expired or invalid. Please request a new one.')
 
 
 def test_request_new_token(selenium, mails, get_registration_info):
-	_navigate_self_service(selenium, '#page=createaccount')
+	_navigate_self_service(selenium, 'createaccount')
 	info = get_registration_info()
-	_enter_attributes(selenium, info['attributes'], 'Create account')
-	_navigate_self_service(selenium, '#page=verifyaccount')
+	_enter_attributes(selenium, info['attributes'])
+	_navigate_self_service(selenium, 'verifyaccount')
+	time.sleep(2)
 	_enter_attributes(selenium, {
-		'username': info['attributes']['username']
-	}, 'Request new token')
-	registered_text = ', we have sent you an email to your registered address. Please follow the instructions in the email to verify your account.'
-	selenium.driver.find_element_by_xpath('//p[text()="Hello "]/b[text()="{}"]//parent::p[text()="{}"]'.format(info['attributes']['username'], registered_text))
+		'username': info['attributes']['username'],
+	})
+	time.sleep(3)
+	selenium.wait_for_text('Please follow the instructions in the email to verify your account')
 	mail = _get_mail(mails)
 	selenium.driver.refresh()
 	selenium.driver.get(mail['auto_verify_link'])
 	selenium.wait_until_standby_animation_appears_and_disappears()
-	verified_text = ', your account has been successfully verified.'
-	selenium.driver.find_element_by_xpath('//p[text()="Welcome "]/b[text()="{}"]//parent::p[text()="{}"]'.format(info['attributes']['username'], verified_text))
-	selenium.driver.find_element_by_xpath('//p[text()="Continue to the "]/a[text()="Univention Portal"]')
+	click_submit(selenium)
+	selenium.wait_for_text('Your account has been successfully verified')
 
 
 def test_next_steps(selenium, mails, ucr, get_registration_info):
 	ucr.handler_set(['umc/self-service/account-verification/next-steps=Foo Bar'])
-	_navigate_self_service(selenium, '#page=createaccount')
+	_navigate_self_service(selenium, 'createaccount')
 	info = get_registration_info()
-	_enter_attributes(selenium, info['attributes'], 'Create account')
+	_enter_attributes(selenium, info['attributes'])
+	selenium.wait_until_standby_animation_appears_and_disappears()
 	mail = _get_mail(mails)
 	selenium.driver.get(mail['auto_verify_link'])
-	selenium.wait_until_standby_animation_appears_and_disappears()
-	selenium.driver.find_element_by_xpath('//p[text()="Welcome "]/b[text()="{}"]//parent::p[text()=", your account has been successfully verified."]'.format(info['attributes']['username']))
-	selenium.driver.find_element_by_xpath('//p[text()="Foo Bar"]')
+	click_submit(selenium)
+	time.sleep(1)
+	selenium.wait_for_text('Your account has been successfully verified')
 
 
 @pytest.mark.parametrize("change_email", [True, False])
 def test_email_change(selenium, mails, get_registration_info, change_email):
-	_navigate_self_service(selenium, '#page=createaccount')
+	_navigate_self_service(selenium, 'createaccount')
 	info = get_registration_info()
-	_enter_attributes(selenium, info['attributes'], 'Create account')
+	_enter_attributes(selenium, info['attributes'])
+	selenium.wait_until_standby_animation_appears_and_disappears()
 	mail = _get_mail(mails)
 	selenium.driver.get(mail['auto_verify_link'])
 	selenium.wait_until_standby_animation_appears_and_disappears()
+	click_submit(selenium)
 	utils.verify_ldap_object(info['dn'], {
 		'univentionRegisteredThroughSelfService': ['TRUE'],
 		'univentionPasswordRecoveryEmailVerified': ['TRUE'],
-	})
-	_navigate_self_service(selenium, '#page=setcontactinformation')
+	}, retry_count=1, delay=2)
+	_navigate_self_service(selenium, 'protectaccount')
+	selenium.wait_until_standby_animation_appears_and_disappears()
 	selenium.enter_input('username', info['attributes']['username'])
 	selenium.enter_input('password', info['attributes']['password'])
-	selenium.click_button('Next')
+	click_submit(selenium)
 	selenium.wait_for_text('Email')
-	verified_text = 'Your account has to be verified again after changing your email. We have sent you an email to '
 	if change_email:
 		new_email = 'foo@bar.com'
-		e = selenium.driver.find_element_by_id('email')
+		e = selenium.driver.find_element_by_name('email')
 		e.clear()
 		e.send_keys(new_email)
-		e = selenium.driver.find_element_by_id('email_check')
+		e = selenium.driver.find_element_by_name('email--retype')
 		e.clear()
 		e.send_keys(new_email)
-		selenium.click_button('Save')
-		selenium.wait_for_text('Your contact data has been successfully changed.')
-		selenium.driver.find_element_by_xpath('//p[text()="{}"]'.format(verified_text))
-		selenium.driver.find_element_by_xpath('//p[text()="{}"]/b[text()="{}"]//parent::p[text()=". Please follow the instructions in the email to verify your account."]'.format(verified_text, new_email))
+		click_submit(selenium)
+		time.sleep(2)
+		selenium.wait_for_text('Your account recovery options have been updated.. Your account has to be verified again')
 	else:
-		selenium.click_button('Save')
-		selenium.wait_for_text('Your contact data has been successfully changed.')
-		with pytest.raises(NoSuchElementException):
-			selenium.driver.find_element_by_xpath('//p[text()="{}"]'.format(verified_text))
+		click_submit(selenium)
+		with pytest.raises(TimeoutException):
+			selenium.wait_for_text('Your account recovery options have been updated.. Your account has to be verified again')
